
# q-expansion of newform 825.2.bx.f, downloaded from the LMFDB on 06 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 825
weight = 2
poly_data = [1, 0, -1, 0, 15, 0, -59, 0, 104, 0, -59, 0, 15, 0, -1, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-63, 0, -622, 0, 1045, 0, 772, 0, -908, 0, 289, 0, 2, 0, 21, 0], 384], [[-119, 0, 1498, 0, -1995, 0, 2436, 0, -1260, 0, 329, 0, -22, 0, 21, 0], 384], [[0, 119, 0, -1498, 0, 1995, 0, -2436, 0, 1260, 0, -329, 0, 22, 0, -21], 384], [[-40, 0, 137, 0, -671, 0, 804, 0, -384, 0, 76, 0, -11, 0, 5, 0], 96], [[91, 0, -246, 0, 475, 0, -1604, 0, 1084, 0, -309, 0, 10, 0, -21, 0], 192], [[30, 0, 155, 0, -1107, 0, 1332, 0, -648, 0, 138, 0, -17, 0, 9, 0], 96], [[0, 30, 0, 155, 0, -1107, 0, 1332, 0, -648, 0, 138, 0, -17, 0, 9], 96], [[0, -16, 0, -685, 0, 1867, 0, -1748, 0, 736, 0, -148, 0, 23, 0, -9], 96], [[77, 0, 466, 0, -1511, 0, 4564, 0, -2972, 0, 845, 0, -30, 0, 57, 0], 384], [[0, 685, 0, -1990, 0, 2945, 0, -5644, 0, 3428, 0, -947, 0, 42, 0, -63], 384], [[-58, 0, 201, 0, -101, 0, -1108, 0, 824, 0, -246, 0, 5, 0, -17, 0], 96], [[0, -58, 0, 201, 0, -101, 0, -1108, 0, 824, 0, -246, 0, 5, 0, -17], 96], [[0, -543, 0, 2666, 0, -9107, 0, 10980, 0, -5388, 0, 1185, 0, -134, 0, 77], 384], [[0, 97, 0, -71, 0, -1556, 0, 3776, 0, -2284, 0, 589, 0, -35, 0, 40], 96]]

hecke_ring_character_values = [[551, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [727, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [376, [0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -1, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, -1, 0, 0], [1, 0, -2, -1, 0, -3, -3, -2, 0, 0, -2, 0, 2, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -1, 1, -1], [0, 2, 0, 0, 2, 0, 0, 0, -2, 0, 0, 0, 0, 0, 1, 0], [0, 0, 1, 0, 0, 0, -1, 0, 0, 0, 1, 0, 2, 0, 0, 0], [0, 0, 0, 0, -4, 0, 0, 0, 1, -1, 0, -2, 0, -4, -2, 1], [0, 0, 0, -3, 0, 1, 1, -6, 0, 0, -5, 0, 3, 0, 0, 0], [5, 0, 1, -1, 0, -4, 1, -5, 0, 0, 0, 0, 0, 0, 0, 0], [0, -3, 0, 0, 3, 0, 0, 0, -3, 5, 0, 1, 0, -3, 0, -1], [-4, 0, 1, 4, 0, 0, 0, 0, 0, 0, 1, 0, -8, 0, 0, 0], [0, 0, 0, 0, 5, 0, 0, 0, 0, 1, 0, 4, 0, 5, 4, -1], [0, -5, 0, 0, 0, 0, 0, 0, 1, -2, 0, 0, 0, -1, -2, 0], [0, 3, 0, 0, 3, 0, 0, 0, 0, 0, 0, 1, 0, 3, -6, 6], [0, 0, 0, -2, 0, 2, 2, -6, 0, 0, -3, 0, 2, 0, 0, 0], [3, 0, -6, 2, 0, 1, 0, 2, 0, 0, 1, 0, 3, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 3, -4, 0, 3, 0, 0, 3, 4], [4, 0, -2, -9, 0, -5, 0, -9, 0, 0, -5, 0, 4, 0, 0, 0], [0, 5, 0, 0, 5, 0, 0, 0, -5, 3, 0, 4, 0, 5, 0, -4], [5, 0, 4, -4, 0, 2, 4, -5, 0, 0, 0, 0, 0, 0, 0, 0], [0, 3, 0, 0, 1, 0, 0, 0, -3, 5, 0, 5, 0, 0, 0, 0], [5, 0, -8, 0, 0, -8, -4, -3, 0, 0, -4, 0, 3, 0, 0, 0], [0, -1, 0, 0, -1, 0, 0, 0, 0, 0, 0, 7, 0, -5, 2, -2], [-12, 0, -2, 12, 0, -3, -2, 12, 0, 0, 0, 0, 0, 0, 0, 0], [0, 4, 0, 0, 9, 0, 0, 0, -9, 6, 0, 2, 0, 4, 0, -2], [0, 8, 0, 0, 0, 0, 0, 0, -3, -4, 0, 0, 0, 3, -4, -2], [1, 0, 1, 0, 0, 1, 0, -7, 0, 0, 0, 0, 7, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 5, -13, 0, 0, 0, -5, -13, 5], [0, -1, 0, 0, -2, 0, 0, 0, 1, -1, 0, -1, 0, 0, -7, 0], [-9, 0, 6, 0, 0, 6, 5, 4, 0, 0, 5, 0, -4, 0, 0, 0], [0, 0, 0, 0, -11, 0, 0, 0, 0, -1, 0, -1, 0, 0, 1, 0], [0, 0, 0, 3, 0, 13, 13, 11, 0, 0, 2, 0, -3, 0, 0, 0], [-1, 0, -7, 7, 0, -4, 0, 7, 0, 0, -4, 0, -1, 0, 0, 0], [13, 0, 4, -13, 0, 0, 8, 0, 0, 0, 4, 0, 6, 0, 0, 0], [0, 4, 0, 0, 0, 0, 0, 0, -3, -9, 0, 0, 0, 3, -9, 4], [0, -6, 0, 0, -6, 0, 0, 0, 0, 0, 0, 5, 0, -6, 9, -9], [0, 4, 0, 0, 4, 0, 0, 0, 0, 0, 0, 6, 0, 10, 12, -12], [0, 1, 0, 0, 0, 0, 0, 0, -4, 14, 0, 0, 0, 4, 14, -7], [4, 0, -5, -4, 0, 0, 1, 0, 0, 0, -5, 0, 6, 0, 0, 0], [9, 0, 6, -15, 0, 5, 0, -15, 0, 0, 5, 0, 9, 0, 0, 0], [0, 0, 0, 7, 0, 3, 3, 8, 0, 0, 7, 0, -7, 0, 0, 0], [0, 8, 0, 0, 12, 0, 0, 0, -8, 12, 0, 12, 0, 0, 3, 0], [0, 0, 0, 0, -9, 0, 0, 0, 0, -3, 0, 0, 0, -9, 0, 3], [-7, 0, 8, 0, 0, 8, 13, 12, 0, 0, 13, 0, -12, 0, 0, 0], [-2, 0, 9, -4, 0, 9, 9, 2, 0, 0, 0, 0, 0, 0, 0, 0], [0, -4, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 11, -7], [0, 7, 0, 0, 1, 0, 0, 0, -1, 4, 0, -2, 0, 7, 0, 2], [5, 0, 3, -12, 0, 3, 3, -5, 0, 0, 0, 0, 0, 0, 0, 0], [0, -2, 0, 0, -2, 0, 0, 0, 0, 0, 0, -2, 0, 9, 11, -11], [-4, 0, 11, 4, 0, 0, -2, 0, 0, 0, 11, 0, 0, 0, 0, 0], [-13, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, -6, 0, 0, 0], [0, 0, 2, 9, 0, 4, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -4, 0, 0, -3, 0, 0, 0, 3, 10, 0, 6, 0, -4, 0, -6], [0, 0, 0, 0, -7, 0, 0, 0, -4, -9, 0, -16, 0, -7, -16, 9], [-5, 0, 11, 6, 0, 5, 0, 6, 0, 0, 5, 0, -5, 0, 0, 0], [0, 0, 0, -18, 0, 4, 4, -18, 0, 0, -5, 0, 18, 0, 0, 0], [0, -7, 0, 0, -7, 0, 0, 0, 0, 0, 0, -16, 0, -8, -1, 1], [13, 0, -14, -9, 0, -2, 0, -9, 0, 0, -2, 0, 13, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 0, -6, -2, 0, 0, 0, 6, -2, -2], [0, -10, 0, 0, 3, 0, 0, 0, -3, 11, 0, 6, 0, -10, 0, -6], [0, 0, 0, 0, 7, 0, 0, 0, 6, 19, 0, 17, 0, 7, 17, -19], [-10, 0, 1, 10, 0, 0, 6, 0, 0, 0, 1, 0, -7, 0, 0, 0], [0, 2, 0, 0, -6, 0, 0, 0, -2, -1, 0, -1, 0, 0, -9, 0], [0, -6, 0, 0, -6, 0, 0, 0, 0, 0, 0, -10, 0, -2, 0, 0], [0, 0, 5, 0, 0, 5, 0, 8, 0, 0, 0, 0, -8, 0, 0, 0], [0, 6, 0, 0, 9, 0, 0, 0, -9, -4, 0, -8, 0, 6, 0, 8], [0, 6, 0, 0, 7, 0, 0, 0, -6, -17, 0, -17, 0, 0, -22, 0], [-3, 0, -3, 3, 0, 0, -3, 0, 0, 0, -3, 0, 6, 0, 0, 0], [0, 0, 0, 0, 10, 0, 0, 0, 10, -4, 0, 5, 0, 10, 5, 4], [0, 0, 0, 2, 0, -19, -19, -10, 0, 0, 0, 0, -2, 0, 0, 0], [0, 5, 0, 0, 12, 0, 0, 0, -12, 16, 0, 4, 0, 5, 0, -4], [0, 0, 0, 0, -9, 0, 0, 0, 5, -15, 0, -12, 0, -9, -12, 15], [6, 0, 5, -19, 0, 5, 0, -19, 0, 0, 5, 0, 6, 0, 0, 0], [0, 15, 0, 0, 15, 0, 0, 0, 0, 0, 0, 15, 0, 9, 2, -2], [0, 0, 0, 2, 0, 5, 5, 7, 0, 0, 14, 0, -2, 0, 0, 0], [0, 0, 0, 0, 4, 0, 0, 0, -5, 20, 0, 8, 0, 4, 8, -20], [5, 0, -7, -6, 0, -4, 0, -6, 0, 0, -4, 0, 5, 0, 0, 0], [0, 0, 8, -2, 0, 4, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-22, 0, -5, 0, 0, -5, -12, 16, 0, 0, -12, 0, -16, 0, 0, 0], [-8, 0, -9, 8, 0, 0, -10, 0, 0, 0, -9, 0, -3, 0, 0, 0], [-13, 0, 4, 4, 0, -4, 4, 13, 0, 0, 0, 0, 0, 0, 0, 0], [0, 4, 0, 0, 11, 0, 0, 0, -11, 1, 0, -9, 0, 4, 0, 9], [-19, 0, -5, 0, 0, -5, -1, 13, 0, 0, -1, 0, -13, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -10, -1, 0, 0, 0, 10, -1, -4], [6, 0, -21, 9, 0, -14, -21, -6, 0, 0, 0, 0, 0, 0, 0, 0], [0, 15, 0, 0, 3, 0, 0, 0, -15, 7, 0, 7, 0, 0, -12, 0], [-12, 0, -20, 0, 0, -20, -22, -5, 0, 0, -22, 0, 5, 0, 0, 0], [0, 0, 0, 0, -16, 0, 0, 0, 18, -26, 0, -23, 0, -16, -23, 26], [0, -4, 0, 0, 19, 0, 0, 0, 4, 16, 0, 16, 0, 0, -5, 0], [-6, 0, 2, -6, 0, -3, 0, -6, 0, 0, -3, 0, -6, 0, 0, 0], [0, -10, 0, 0, 0, 0, 0, 0, 10, -9, 0, 0, 0, -10, -9, -6], [0, 0, 0, -7, 0, 3, 3, 11, 0, 0, 0, 0, 7, 0, 0, 0], [0, 0, 0, 21, 0, 1, 1, 4, 0, 0, -1, 0, -21, 0, 0, 0], [0, 20, 0, 0, 0, 0, 0, 0, -8, 0, 0, 0, 0, 8, 0, -11], [9, 0, -2, -9, 0, 0, 25, 0, 0, 0, -2, 0, -7, 0, 0, 0], [0, 0, 0, 10, 0, 2, 2, -9, 0, 0, 3, 0, -10, 0, 0, 0], [0, -7, 0, 0, -5, 0, 0, 0, 7, -3, 0, -3, 0, 0, -5, 0], [-17, 0, -6, 9, 0, -3, -6, 17, 0, 0, 0, 0, 0, 0, 0, 0], [0, 14, 0, 0, 0, 0, 0, 0, -4, -9, 0, 0, 0, 4, -9, 23], [0, 3, 0, 0, -8, 0, 0, 0, 8, -22, 0, -14, 0, 3, 0, 14], [0, -5, 0, 0, -5, 0, 0, 0, 0, 0, 0, 5, 0, -3, -12, 12], [-6, 0, -1, 6, 0, 0, -1, 0, 0, 0, -1, 0, 10, 0, 0, 0], [18, 0, 14, 0, 0, 14, 13, -4, 0, 0, 13, 0, 4, 0, 0, 0], [0, 1, 0, 0, -17, 0, 0, 0, -1, -12, 0, -12, 0, 0, 6, 0], [0, -13, 0, 0, 2, 0, 0, 0, -2, 30, 0, 12, 0, -13, 0, -12], [0, 0, 0, 0, 10, 0, 0, 0, -4, 31, 0, 20, 0, 10, 20, -31], [22, 0, 6, -27, 0, 6, 0, -27, 0, 0, 6, 0, 22, 0, 0, 0], [0, 0, 0, 8, 0, -12, -12, 1, 0, 0, 11, 0, -8, 0, 0, 0], [0, -10, 0, 0, -10, 0, 0, 0, 0, 0, 0, 0, 0, -19, 8, -8], [0, 9, 0, 0, 0, 0, 0, 0, 10, -5, 0, 0, 0, -10, -5, 17], [0, 0, 0, 0, 11, 0, 0, 0, 1, -11, 0, 6, 0, 11, 6, 11], [-4, 0, -6, 4, 0, 0, -8, 0, 0, 0, -6, 0, 27, 0, 0, 0], [0, 0, 0, -18, 0, 0, 0, -22, 0, 0, -25, 0, 18, 0, 0, 0], [-7, 0, -3, 7, 0, 0, -14, 0, 0, 0, -3, 0, 7, 0, 0, 0], [0, -10, 0, 0, 8, 0, 0, 0, 10, -17, 0, -17, 0, 0, 4, 0], [0, 21, 0, 0, 21, 0, 0, 0, 0, 0, 0, 13, 0, 16, 4, -4], [0, -4, 0, 0, -4, 0, 0, 0, 4, 1, 0, -7, 0, -4, 0, 7], [-3, 0, 8, 0, 0, 8, -4, -4, 0, 0, -4, 0, 4, 0, 0, 0], [-15, 0, 12, 0, 0, 12, 12, 34, 0, 0, 12, 0, -34, 0, 0, 0], [0, -1, 0, 0, -1, 0, 0, 0, 0, 0, 0, 3, 0, -26, -4, 4], [0, -7, 0, 0, -30, 0, 0, 0, 7, -27, 0, -27, 0, 0, -16, 0], [0, 0, 0, 0, 26, 0, 0, 0, -10, 27, 0, 22, 0, 26, 22, -27], [-15, 0, -4, -9, 0, 5, -4, 15, 0, 0, 0, 0, 0, 0, 0, 0], [-8, 0, -2, 8, 0, 0, -11, 0, 0, 0, -2, 0, -20, 0, 0, 0], [-9, 0, -26, 14, 0, -4, 0, 14, 0, 0, -4, 0, -9, 0, 0, 0], [0, 0, 0, 19, 0, 7, 7, 28, 0, 0, 16, 0, -19, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 10, -32, 0, -28, 0, 0, -28, 32], [0, 20, 0, 0, 1, 0, 0, 0, -1, 6, 0, 7, 0, 20, 0, -7], [-26, 0, 17, 17, 0, 19, 17, 26, 0, 0, 0, 0, 0, 0, 0, 0], [0, -7, 0, 0, -5, 0, 0, 0, 7, 8, 0, 8, 0, 0, 17, 0], [30, 0, 8, -30, 0, 0, 13, 0, 0, 0, 8, 0, 22, 0, 0, 0], [0, -6, 0, 0, -6, 0, 0, 0, 0, 0, 0, -12, 0, -16, -10, 10], [-11, 0, -5, 27, 0, 12, -5, 11, 0, 0, 0, 0, 0, 0, 0, 0], [9, 0, 12, 0, 0, 12, 10, 4, 0, 0, 10, 0, -4, 0, 0, 0], [0, 10, 0, 0, 0, 0, 0, 0, -7, -26, 0, 0, 0, 7, -26, 9], [0, -1, 0, 0, -3, 0, 0, 0, 1, -12, 0, -12, 0, 0, 13, 0], [0, -5, 0, 0, 3, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 0], [-36, 0, -4, 18, 0, 3, 0, 18, 0, 0, 3, 0, -36, 0, 0, 0], [-18, 0, -6, 18, 0, 0, -3, 0, 0, 0, -6, 0, 9, 0, 0, 0], [0, 0, 0, -9, 0, 6, 6, -2, 0, 0, -5, 0, 9, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 35, 0, 5, 12, -12], [0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 41, 0, -4, 8, -8], [0, 0, 0, -3, 0, 7, 7, 3, 0, 0, 1, 0, 3, 0, 0, 0], [14, 0, 20, -14, 0, 0, 0, 0, 0, 0, 20, 0, -15, 0, 0, 0], [0, -8, 0, 0, -1, 0, 0, 0, 8, 10, 0, 10, 0, 0, -17, 0], [0, 0, 0, 0, -3, 0, 0, 0, -10, 0, 0, -14, 0, -3, -14, 0], [9, 0, -11, 0, 0, -11, -13, 4, 0, 0, -13, 0, -4, 0, 0, 0], [0, 2, 0, 0, 9, 0, 0, 0, -2, 17, 0, 17, 0, 0, -6, 0], [0, 22, 0, 0, 0, 0, 0, 0, -1, -9, 0, 0, 0, 1, -9, 16], [-6, 0, 0, 0, 0, 0, 15, 27, 0, 0, 15, 0, -27, 0, 0, 0], [0, -18, 0, 0, 0, 0, 0, 0, -4, 17, 0, 0, 0, 4, 17, -6], [0, 5, 0, 0, 3, 0, 0, 0, -3, 16, 0, 14, 0, 5, 0, -14], [0, -2, 0, 0, -8, 0, 0, 0, 2, 16, 0, 16, 0, 0, 19, 0], [3, 0, 4, 7, 0, -10, 4, -3, 0, 0, 0, 0, 0, 0, 0, 0], [-14, 0, 10, 2, 0, 9, 0, 2, 0, 0, 9, 0, -14, 0, 0, 0], [29, 0, 14, -9, 0, -5, 0, -9, 0, 0, -5, 0, 29, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 29, 4, -4], [13, 0, 6, -17, 0, -4, 0, -17, 0, 0, -4, 0, 13, 0, 0, 0], [0, 0, 0, 0, 11, 0, 0, 0, -8, -11, 0, -10, 0, 11, -10, 11], [0, 13, 0, 0, -1, 0, 0, 0, 1, -24, 0, -21, 0, 13, 0, 21], [0, 0, 0, 0, 10, 0, 0, 0, -7, -12, 0, 5, 0, 10, 5, 12], [-4, 0, 24, 4, 0, 0, 6, 0, 0, 0, 24, 0, -10, 0, 0, 0], [0, -19, 0, 0, -19, 0, 0, 0, 0, 0, 0, 5, 0, -27, -7, 7], [0, -17, 0, 0, -18, 0, 0, 0, 18, -12, 0, -6, 0, -17, 0, 6], [13, 0, -8, 0, 0, -8, 11, -12, 0, 0, 11, 0, 12, 0, 0, 0], [0, 10, 0, 0, 16, 0, 0, 0, -16, -2, 0, -12, 0, 10, 0, 12]]
